Crate aurochs

Crate aurochs 

Aurochs

Pronounced O-rocks

Usage:

Aurochs is a html generator. Using a similar syntax to JavaScript, easily create templates, generate html and create amazing applications.

Brings some of the JavaScript functionality of creating HTML elements to Rust

Some use cases may include:

  1. A server side application where you use Rust to generate the HTML and you send the generated string as the request result
  2. A static site generator where you create a blog template which takes a set of arguments and returns a html representation
  3. A frontend generator for applications making use of html, such as Tauri and Electron

Structs

Document
The root Element of the HTML Tree
Node
A mutable struct composed of a tag, attribute list, child list and closing type.