Aurochs
Pronounced O-rocks
Usage:
Aurochs is a html generator. Using a similar syntax to JavaScript, easily create templates, generate html and create amazing applications.
Brings some of the JavaScript functionality of creating HTML elements to Rust
Some use cases may include:
- A server side application where you use Rust to generate the HTML and you send the generated string as the request result
- A static site generator where you create a blog template which takes a set of arguments and returns a html representation
- A frontend generator for applications making use of html, such as Tauri and Electron